@@ -1,4 +1,3 @@
-from abstract.abc_http_client import BaseApiCollector
 from time import sleep
 from enum import Enum
 
@@ -13,9 +12,11 @@ class HttpMethod(Enum):
     DELETE = 'DELETE'
 
 
-class SyncApiCollector(BaseApiCollector):
+class SyncApiCollector:
     def __init__(self, main_api_link: str, main_params: str = None, cookie: dict = None):
-        super(SyncApiCollector, self).__init__(main_api_link, main_params, cookie)
+        self.main_api_link = main_api_link
+        self.main_api_params = main_params
+        self.cookie = cookie
         self.session = Session()
 
     def push_request(self, method: str, http_method: HttpMethod, params: dict = None) -> Response:
